@@ -1,5 +1,5 @@
 package Git::ObjectStore;
-$Git::ObjectStore::VERSION = '0.002';
+$Git::ObjectStore::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -183,13 +183,13 @@ sub current_commit_id
 
 
 
-sub write_file
+sub write_and_check
 {
     my $self = shift;
     my $filename = shift;
     my $data = shift;
 
-    croak('write_file() is called for a read-only ObjectStore object')
+    croak('write_and_check() is called for a read-only ObjectStore object')
         unless $self->{'writer'};
 
     my $prev_blob_id = '';
@@ -205,7 +205,7 @@ sub write_file
 
 
 
-sub write_file_nocheck
+sub write_file
 {
     my $self = shift;
     my $filename = shift;
@@ -431,7 +431,7 @@ Git::ObjectStore - abstraction layer for Git::Raw and libgit2
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -443,8 +443,8 @@ version 0.002
                                    'writer' => 1);
 
   # write the documents into the store
-  my $is_changed = $store->write_file('docs/001a', \$doc1text);
-  $store->write_file_nocheck('docs/001b', \$doc2text);
+  my $is_changed = $store->write_and_check('docs/001a', \$doc1text);
+  $store->write_file('docs/001b', \$doc2text);
 
   # documents can be read from the writer object
   my $doc = $store->read_file('docs/001c');
@@ -487,11 +487,11 @@ version 0.002
 
 =head1 DESCRIPTION
 
-This module provides an abstraction level on top of L<Git::Raw>, a Perl
+This module provides an abstraction layer on top of L<Git::Raw>, a Perl
 wrapper for F<libgit2>, in order to use a bare Git repository as an
 object store. The objects are written into a mempack, and then flushed
 to disk, so thousands of objects can be created without polluting your
-filesystem and exxhausting its inode pool.
+filesystem and exhausting its inode pool.
 
 =head1 METHODS
 
@@ -562,7 +562,7 @@ This method returns true if the given file extsis in the branch.
 Returns the current commit identifier. This can be useful for detecting
 if there are any changes in the branch and retrieve the difference.
 
-=head2 write_file($path, $data)
+=head2 write_and_check($path, $data)
 
 This method writes the data scalar to the repository under specified
 file name. It returns true if the data differs from the previous version
@@ -570,11 +570,11 @@ or a new file is created. It returns false if the new data is identical
 to what has been written before. The data can be a scalar or a reference
 to scalar.
 
-=head2 write_file_nocheck($path, $data)
+=head2 write_file($path, $data)
 
-This method is similar to C<write_file>, but it does not compare the
-content revisions. It is useful for massive write operations where speed
-is important.
+This method is similar to C<write_and_check>, but it does not compare
+the content revisions. It is useful for massive write operations where
+speed is important.
 
 =head2 delete_file($path)
 
